"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
This file is named backup_commands to avoid conflicting header files with top-most backup.proto"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CheckBackupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SILENT_FIELD_NUMBER: builtins.int
    silent: builtins.bool
    def __init__(
        self,
        *,
        silent: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["silent", b"silent"]) -> None: ...

global___CheckBackupRequest = CheckBackupRequest

@typing.final
class CheckBackupResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id"]) -> None: ...

global___CheckBackupResponse = CheckBackupResponse

@typing.final
class CreateBackupRequest(google.protobuf.message.Message):
    """Timestamp must be in UTC"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIMESTAMP_FIELD_NUMBER: builtins.int
    TIMEZONE_OFFSET_FIELD_NUMBER: builtins.int
    timestamp: builtins.int
    timezone_offset: builtins.int
    def __init__(
        self,
        *,
        timestamp: builtins.int = ...,
        timezone_offset: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["timestamp", b"timestamp", "timezone_offset", b"timezone_offset"]) -> None: ...

global___CreateBackupRequest = CreateBackupRequest

@typing.final
class ListBackupsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListBackupsRequest = ListBackupsRequest

@typing.final
class BackupInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    id: builtins.str
    timestamp: builtins.int
    name: builtins.str
    """uint32 timezone_offset = 3;"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        timestamp: builtins.int = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "name", b"name", "timestamp", b"timestamp"]) -> None: ...

global___BackupInfo = BackupInfo

@typing.final
class ListBackupsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BackupInfo]: ...
    def __init__(
        self,
        *,
        info: collections.abc.Iterable[global___BackupInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["info", b"info"]) -> None: ...

global___ListBackupsResponse = ListBackupsResponse

@typing.final
class RestoreBackupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    TIMEZONE_OFFSET_FIELD_NUMBER: builtins.int
    id: builtins.str
    timestamp: builtins.int
    timezone_offset: builtins.int
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        timestamp: builtins.int = ...,
        timezone_offset: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "timestamp", b"timestamp", "timezone_offset", b"timezone_offset"]) -> None: ...

global___RestoreBackupRequest = RestoreBackupRequest
