# Copyright 2019 Shift Cryptosecurity AG
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Abstraction for the transport layer used for transmitting U2F messages."""

from .communication import PhysicalLayer, TransportLayer
from .bitbox_api_protocol import (
    BitBoxNoiseConfig,
    BitBoxCommonAPI,
    Bitbox02Exception,
    UserAbortException,
    AttestationException,
    FirmwareVersionOutdatedException,
    LibraryVersionOutdatedException,
    ERR_DUPLICATE_ENTRY,
    ERR_GENERIC,
    ERR_USER_ABORT,
    HARDENED,
)
