"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
This function can be used to get an identifying xpub at the keypath m/4541509'/1112098098'"
The keypath argument has to be m/4541509'/1112098098'
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.empty_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ElectrumEncryptionKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEYPATH_FIELD_NUMBER: builtins.int
    @property
    def keypath(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        keypath: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["keypath", b"keypath"]) -> None: ...

global___ElectrumEncryptionKeyRequest = ElectrumEncryptionKeyRequest

@typing.final
class ElectrumEncryptionKeyResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    key: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key", b"key"]) -> None: ...

global___ElectrumEncryptionKeyResponse = ElectrumEncryptionKeyResponse

@typing.final
class BIP85Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class AppLn(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ACCOUNT_NUMBER_FIELD_NUMBER: builtins.int
        account_number: builtins.int
        def __init__(
            self,
            *,
            account_number: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["account_number", b"account_number"]) -> None: ...

    BIP39_FIELD_NUMBER: builtins.int
    LN_FIELD_NUMBER: builtins.int
    @property
    def bip39(self) -> google.protobuf.empty_pb2.Empty: ...
    @property
    def ln(self) -> global___BIP85Request.AppLn: ...
    def __init__(
        self,
        *,
        bip39: google.protobuf.empty_pb2.Empty | None = ...,
        ln: global___BIP85Request.AppLn | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["app", b"app", "bip39", b"bip39", "ln", b"ln"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["app", b"app", "bip39", b"bip39", "ln", b"ln"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["app", b"app"]) -> typing.Literal["bip39", "ln"] | None: ...

global___BIP85Request = BIP85Request

@typing.final
class BIP85Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BIP39_FIELD_NUMBER: builtins.int
    LN_FIELD_NUMBER: builtins.int
    ln: builtins.bytes
    @property
    def bip39(self) -> google.protobuf.empty_pb2.Empty: ...
    def __init__(
        self,
        *,
        bip39: google.protobuf.empty_pb2.Empty | None = ...,
        ln: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["app", b"app", "bip39", b"bip39", "ln", b"ln"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["app", b"app", "bip39", b"bip39", "ln", b"ln"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["app", b"app"]) -> typing.Literal["bip39", "ln"] | None: ...

global___BIP85Response = BIP85Response
