"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PerformAttestationRequest(google.protobuf.message.Message):
    """Deprecated, last used in v1.0.0"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHALLENGE_FIELD_NUMBER: builtins.int
    challenge: builtins.bytes
    """32 bytes challenge."""
    def __init__(
        self,
        *,
        challenge: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["challenge", b"challenge"]) -> None: ...

global___PerformAttestationRequest = PerformAttestationRequest

@typing.final
class PerformAttestationResponse(google.protobuf.message.Message):
    """Deprecated, last used in v1.0.0"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOOTLOADER_HASH_FIELD_NUMBER: builtins.int
    DEVICE_PUBKEY_FIELD_NUMBER: builtins.int
    CERTIFICATE_FIELD_NUMBER: builtins.int
    ROOT_PUBKEY_IDENTIFIER_FIELD_NUMBER: builtins.int
    CHALLENGE_SIGNATURE_FIELD_NUMBER: builtins.int
    bootloader_hash: builtins.bytes
    device_pubkey: builtins.bytes
    certificate: builtins.bytes
    root_pubkey_identifier: builtins.bytes
    challenge_signature: builtins.bytes
    def __init__(
        self,
        *,
        bootloader_hash: builtins.bytes = ...,
        device_pubkey: builtins.bytes = ...,
        certificate: builtins.bytes = ...,
        root_pubkey_identifier: builtins.bytes = ...,
        challenge_signature: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bootloader_hash", b"bootloader_hash", "certificate", b"certificate", "challenge_signature", b"challenge_signature", "device_pubkey", b"device_pubkey", "root_pubkey_identifier", b"root_pubkey_identifier"]) -> None: ...

global___PerformAttestationResponse = PerformAttestationResponse
