# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bitbox02_system.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x62itbox02_system.proto\x12\x14shiftcrypto.bitbox02\"\x14\n\x12\x43heckSDCardRequest\"\'\n\x13\x43heckSDCardResponse\x12\x10\n\x08inserted\x18\x01 \x01(\x08\"\x13\n\x11\x44\x65viceInfoRequest\"\xd8\x02\n\x12\x44\x65viceInfoResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0binitialized\x18\x02 \x01(\x08\x12\x0f\n\x07version\x18\x03 \x01(\t\x12#\n\x1bmnemonic_passphrase_enabled\x18\x04 \x01(\x08\x12&\n\x1emonotonic_increments_remaining\x18\x05 \x01(\r\x12\x18\n\x10securechip_model\x18\x06 \x01(\t\x12J\n\tbluetooth\x18\x07 \x01(\x0b\x32\x32.shiftcrypto.bitbox02.DeviceInfoResponse.BluetoothH\x00\x88\x01\x01\x1aM\n\tBluetooth\x12\x15\n\rfirmware_hash\x18\x01 \x01(\x0c\x12\x18\n\x10\x66irmware_version\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x42\x0c\n\n_bluetooth\"\x9b\x01\n\x19InsertRemoveSDCardRequest\x12L\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32<.shiftcrypto.bitbox02.InsertRemoveSDCardRequest.SDCardAction\"0\n\x0cSDCardAction\x12\x0f\n\x0bREMOVE_CARD\x10\x00\x12\x0f\n\x0bINSERT_CARD\x10\x01\"\x0e\n\x0cResetRequest\",\n\x18SetDeviceLanguageRequest\x12\x10\n\x08language\x18\x01 \x01(\t\"$\n\x14SetDeviceNameRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"%\n\x12SetPasswordRequest\x12\x0f\n\x07\x65ntropy\x18\x01 \x01(\x0c\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bitbox02_system_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CHECKSDCARDREQUEST._serialized_start=47
  _CHECKSDCARDREQUEST._serialized_end=67
  _CHECKSDCARDRESPONSE._serialized_start=69
  _CHECKSDCARDRESPONSE._serialized_end=108
  _DEVICEINFOREQUEST._serialized_start=110
  _DEVICEINFOREQUEST._serialized_end=129
  _DEVICEINFORESPONSE._serialized_start=132
  _DEVICEINFORESPONSE._serialized_end=476
  _DEVICEINFORESPONSE_BLUETOOTH._serialized_start=385
  _DEVICEINFORESPONSE_BLUETOOTH._serialized_end=462
  _INSERTREMOVESDCARDREQUEST._serialized_start=479
  _INSERTREMOVESDCARDREQUEST._serialized_end=634
  _INSERTREMOVESDCARDREQUEST_SDCARDACTION._serialized_start=586
  _INSERTREMOVESDCARDREQUEST_SDCARDACTION._serialized_end=634
  _RESETREQUEST._serialized_start=636
  _RESETREQUEST._serialized_end=650
  _SETDEVICELANGUAGEREQUEST._serialized_start=652
  _SETDEVICELANGUAGEREQUEST._serialized_end=696
  _SETDEVICENAMEREQUEST._serialized_start=698
  _SETDEVICENAMEREQUEST._serialized_end=734
  _SETPASSWORDREQUEST._serialized_start=736
  _SETPASSWORDREQUEST._serialized_end=773
# @@protoc_insertion_point(module_scope)
