# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bluetooth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x62luetooth.proto\x12\x14shiftcrypto.bitbox02\"\x1f\n\x1d\x42luetoothToggleEnabledRequest\"6\n\x1b\x42luetoothUpgradeInitRequest\x12\x17\n\x0f\x66irmware_length\x18\x01 \x01(\r\"%\n\x15\x42luetoothChunkRequest\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x12\n\x10\x42luetoothSuccess\"?\n\x1d\x42luetoothRequestChunkResponse\x12\x0e\n\x06offset\x18\x01 \x01(\r\x12\x0e\n\x06length\x18\x02 \x01(\r\"\xf5\x01\n\x10\x42luetoothRequest\x12I\n\x0cupgrade_init\x18\x01 \x01(\x0b\x32\x31.shiftcrypto.bitbox02.BluetoothUpgradeInitRequestH\x00\x12<\n\x05\x63hunk\x18\x02 \x01(\x0b\x32+.shiftcrypto.bitbox02.BluetoothChunkRequestH\x00\x12M\n\x0etoggle_enabled\x18\x03 \x01(\x0b\x32\x33.shiftcrypto.bitbox02.BluetoothToggleEnabledRequestH\x00\x42\t\n\x07request\"\xa8\x01\n\x11\x42luetoothResponse\x12\x39\n\x07success\x18\x01 \x01(\x0b\x32&.shiftcrypto.bitbox02.BluetoothSuccessH\x00\x12L\n\rrequest_chunk\x18\x02 \x01(\x0b\x32\x33.shiftcrypto.bitbox02.BluetoothRequestChunkResponseH\x00\x42\n\n\x08responseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bluetooth_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BLUETOOTHTOGGLEENABLEDREQUEST._serialized_start=41
  _BLUETOOTHTOGGLEENABLEDREQUEST._serialized_end=72
  _BLUETOOTHUPGRADEINITREQUEST._serialized_start=74
  _BLUETOOTHUPGRADEINITREQUEST._serialized_end=128
  _BLUETOOTHCHUNKREQUEST._serialized_start=130
  _BLUETOOTHCHUNKREQUEST._serialized_end=167
  _BLUETOOTHSUCCESS._serialized_start=169
  _BLUETOOTHSUCCESS._serialized_end=187
  _BLUETOOTHREQUESTCHUNKRESPONSE._serialized_start=189
  _BLUETOOTHREQUESTCHUNKRESPONSE._serialized_end=252
  _BLUETOOTHREQUEST._serialized_start=255
  _BLUETOOTHREQUEST._serialized_end=500
  _BLUETOOTHRESPONSE._serialized_start=503
  _BLUETOOTHRESPONSE._serialized_end=671
# @@protoc_insertion_point(module_scope)
