# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: backup_commands.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x62\x61\x63kup_commands.proto\x12\x14shiftcrypto.bitbox02\"$\n\x12\x43heckBackupRequest\x12\x0e\n\x06silent\x18\x01 \x01(\x08\"!\n\x13\x43heckBackupResponse\x12\n\n\x02id\x18\x01 \x01(\t\"A\n\x13\x43reateBackupRequest\x12\x11\n\ttimestamp\x18\x01 \x01(\r\x12\x17\n\x0ftimezone_offset\x18\x02 \x01(\x05\"\x14\n\x12ListBackupsRequest\"9\n\nBackupInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x04 \x01(\t\"E\n\x13ListBackupsResponse\x12.\n\x04info\x18\x01 \x03(\x0b\x32 .shiftcrypto.bitbox02.BackupInfo\"N\n\x14RestoreBackupRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x17\n\x0ftimezone_offset\x18\x03 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'backup_commands_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CHECKBACKUPREQUEST._serialized_start=47
  _CHECKBACKUPREQUEST._serialized_end=83
  _CHECKBACKUPRESPONSE._serialized_start=85
  _CHECKBACKUPRESPONSE._serialized_end=118
  _CREATEBACKUPREQUEST._serialized_start=120
  _CREATEBACKUPREQUEST._serialized_end=185
  _LISTBACKUPSREQUEST._serialized_start=187
  _LISTBACKUPSREQUEST._serialized_end=207
  _BACKUPINFO._serialized_start=209
  _BACKUPINFO._serialized_end=266
  _LISTBACKUPSRESPONSE._serialized_start=268
  _LISTBACKUPSRESPONSE._serialized_end=337
  _RESTOREBACKUPREQUEST._serialized_start=339
  _RESTOREBACKUPREQUEST._serialized_end=417
# @@protoc_insertion_point(module_scope)
